==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodResourceEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodResourceEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Resource.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.HotRodResourceEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodResourceEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodResourceEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.Resource.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceEntity.HotRodResourceEntitySchema.INSTANCE;
    }
}
